/*!
    \file  disp.h
    \brief demo

    Copyright (c) 2003 HigePon
    WITHOUT ANY WARRANTY

    \author  HigePon
    \version $Revision: 1.9 $
    \date   create:2003/03/09 update:$Date: 2003/07/19 08:35:11 $
*/

#ifndef _MONA_DISP_
#define _MONA_DISP_

#include <types.h>

void disp_name1();
void disp_name2();
void disp_name3();
void disp_name4();
void disp_process();
void disp_kthread_info();
void disp_fd_demo();
void kthread_idle();
void disp_write_font(int x, int y, char ch, byte color);

#endif
